@@ -2,10 +2,10 @@
 Author: LetMeFly
 Date: 2022-01-25 18:07:26
 LastEditors: LetMeFly
-LastEditTime: 2022-03-09 22:53:12
+LastEditTime: 2022-03-10 18:15:13
 '''
 # __all__ = ['AutoGetAndSubmit', 'FromPidToChar', 'GetASourceCodeAndChange', 'GetContestProblemList', 'Login', 'SubmitOneCode']
 from .Login import login
 from .AutoGetAndSubmit import main as finish1contest
 from .SubmitOneCode import submit
-from .EditingAProbem import create1problem
+from .EditingAProbem import create1problem, edit1problem
